@@ -1,5 +1,6 @@
 use std::{
     collections::HashMap,
+    convert::TryFrom,
     task::{Context, Poll},
 };
 
@@ -257,6 +258,14 @@ impl<St: Stream<Item = ChunkStreamItem>> Stream for PartStream<St> {
     }
 }
 
+impl TryFrom<ChunkStream> for PartStream<ChunkStream> {
+    type Error = CondowError;
+
+    fn try_from(chunk_stream: ChunkStream) -> Result<Self, Self::Error> {
+        PartStream::from_chunk_stream(chunk_stream)
+    }
+}
+
 impl<St: Stream<Item = ChunkStreamItem>> AsyncRead for PartStream<St> {
     fn poll_read(
         self: std::pin::Pin<&mut Self>,
